package  
{
import com.kochava.nativeextensions.*;
import com.kochava.nativeextensions.events.*;
import flash.display.Sprite;
import flash.events.Event;
import flash.events.StatusEvent;
import flash.geom.Rectangle;
import flash.system.System;
import flash.text.TextField;

/** Kochava Example App */
public class KochavaExample extends Sprite
{
	//
	// Definitions
	//

	/** Kochava App ID */
	public static const KOCHAVA_ANDROID_APP_ID:String="your_android_app_id";
	public static const KOCHAVA_KINDLE_APP_ID:String="your_kindle_app_id";
	public static const KOCHAVA_IOS_APP_ID:String="your_ios_app_id";

	
	
	//
	// Instance Variables
	//
	
	/** Status */
	private var txtStatus:TextField;
	
	/** Buttons */
	private var buttonContainer:Sprite;
	
	/** Debug display */
	private var txtDebug:TextField;
	
	//
	// Public Methods
	//
	
	/** Create New KochavaExample */
	public function KochavaExample() 
	{		
		createUI();

		if (!Kochava.isSupported())
		{
			log("Kochava is not supported on this platform (not android or ios!)");
			return;
		}

		Kochava._requestAttribution = true;
		Kochava._generateAnonymousKochavaDeviceId = true;


		
		// if you are targeting a single platform and have one app id, you can use the form:
		// Kochava.create("YOUR APP ID");
		// otherwise, pass your iOS app Id, Android App ID, and Kindle App ID in that order.
		// Optional parameters:
		// 4th:  currency type, default is USD.
		// 5th:  logging mode, default is false.  Set to true ONLY during development.
		// 6th:  limit app level ad tracking, default is false.
		// 7th:  identity link key/value pairs array
//		Kochava.create(KOCHAVA_IOS_APP_ID, KOCHAVA_ANDROID_APP_ID, KOCHAVA_KINDLE_APP_ID, "USD", true, true, {InternalId:"internal123", FacebookID:"fb123456"} );
//		Kochava.create(KOCHAVA_IOS_APP_ID, KOCHAVA_ANDROID_APP_ID, KOCHAVA_KINDLE_APP_ID, "USD", false, false, null );
		Kochava.create(KOCHAVA_IOS_APP_ID, KOCHAVA_ANDROID_APP_ID, KOCHAVA_KINDLE_APP_ID, "USD", true );

		// Kochava requests will not fire on iOS devices older than 5.1:
		if (!Kochava.kochava.isKochavaAvailable())
		{
			log("Kochava not available: isKochavaAvailable()="+Kochava.kochava.isKochavaAvailable());
			return;
		}
		
		log("Kochava initialized.");
		Kochava.kochava.setAttributionHandler();
		Kochava.kochava.addEventListener(KochavaEvent.ATTRIBUTION_DATA, onAttributionData);
		Kochava.kochava.addEventListener(KochavaEvent.BEACON_BARRIER_CROSSED, onBeaconBarrierCrossed);
		log("Registered event listeners.");
	}
	
	/** On Receive Attribution Data */
	private function onAttributionData(e:KochavaEvent):void
	{
		log("Attribution Data received. " + "Code: " + e.code + " Level: " + e.level);
	}
	
	/** On Beacon Barrier Crossed */
	private function onBeaconBarrierCrossed(e:KochavaEvent):void
	{
		log("Beacon barrier crossed: " + "Code: " + e.code + " Level: " + e.level);
	}
	
	/** Test Tracking an Event */
	public function testTrackEvent():void
	{
		var valuePayload:Object = {id:"my_id", name:"my_name", duration:60};
		
		log("Tracking event 'myEvent' with data 'myData'...");
		Kochava.kochava.trackEvent("myEvent", JSON.stringify(valuePayload));

//		log("Tracking event 'myEvent' with data 'myData'...");
//		Kochava.kochava.trackEvent("myEvent", "myData");
		//log("trackEvent completed.");
	}
	
	/** Test Tracking a Receipt Event */
	public function testReceiptEvent():void
	{
		var valuePayload:Object = {id:"my_id", name:"my_name", duration:60};
		var encodedReceiptString:String = "___APPLE_RECEIPT_ENCODED_STRING_HERE___"; 

		log("Tracking receipt event 'Purchase' with data 'myData' and encoded string");
		Kochava.kochava.trackEventWithReceipt("Purchase", "myData", encodedReceiptString);
		//log("trackEvent completed.");
	}
	
	/** Test Tracking Spatial Event */
	public function testSpatialEvent():void
	{
		var x:Number=Math.random()*500;
		var y:Number=Math.random()*300;
		var z:Number=Math.random()*400;
		log("Tracking spatial event 'mySpatialEvent' at "+x+","+y+","+z+"...");
		Kochava.kochava.trackSpatialEvent("mySpatialEvent", x, y, z);
		//log("trackSpatialEvent completed.");
	}
	
	/** Test Linking Identity */
	public function testLinkIdentity():void
	{
		log('Linking identity {myInternalUserID:"john123",UserFacebookID:"123456789123456"}...');
		Kochava.kochava.linkIdentity({myInternalUserID:"john123", UserFacebookID:"123456789123456"});
		log("Waiting for linkIdentity response...");
	}
	
	/** Get (Refresh) Attribution Data */
	public function testAttributionData():void
	{
		log("Requesting Attribution Data...");
		trace("testAttributionData fired.");
		var data:String = " No response. "; 
			data = Kochava.kochava.requestAttributionData();
		if (data !== "")
		{
			log("Got Attribution Data.");
			printAttrData(data);
		}
		else
		{	
			log("No Attribution data returned.");
			trace("requestAttributionData() returned blank");
		}
	}
	

	public function testEnableLogging():void
	{
		log("Enabling logging...");
		trace("enable logging fired.");

		Kochava.kochava.enableConsoleLogging(true);

	}
	
	public function testDisableLogging():void
	{
		log("Disable logging...");
		trace("disable logging fired.");

		Kochava.kochava.enableConsoleLogging(false);

	}
	
	public function testLimitAdTrackingTrue():void
	{
		log("setting limit ad tracking TRUE");
		trace("setting limit ad tracking TRUE");

		Kochava.kochava.setLimitAdTracking(true);
	}

	public function testLimitAdTrackingFalse():void
	{
		log("setting limit ad tracking FALSE");
		trace("setting limit at tracking FALSE");

		Kochava.kochava.setLimitAdTracking(false);
	}
	
	public function testDeepLink():void
	{
		log("testing deep link");
		trace("testing deep link");

		com.kochava.nativeextensions.Kochava.kochava.deepLink("some_uri_retrieved_as_the_deeplink");
	}
	

	//
	// Impelementation
	//
	
	/** Create UI */
	public function createUI():void
	{
		txtStatus = new TextField();
		txtStatus.y = 0; //TODO: Buttons at top, log below
		txtStatus.defaultTextFormat=new flash.text.TextFormat("Arial",25);
		txtStatus.width=stage.stageWidth;
		txtStatus.height=40;
		txtStatus.multiline=true;
		txtStatus.wordWrap=true;
		txtStatus.text="Ready";
		addChild(txtStatus);

		if (buttonContainer)
		{
			removeChild(buttonContainer);
			buttonContainer=null;
		}
		
		buttonContainer=new Sprite();
		buttonContainer.y=txtStatus.height;
		addChild(buttonContainer);
		
		var uiRect:Rectangle=new Rectangle(0,0,stage.stageWidth,stage.stageHeight);
		var layout:ButtonLayout=new ButtonLayout(uiRect, 14);
		layout.addButton(new SimpleButton(new Command("Test Event", testTrackEvent)));
		layout.addButton(new SimpleButton(new Command("Test Receipt", testReceiptEvent)));
		//layout.addButton(new SimpleButton(new Command("Test Spatial", testSpatialEvent)));
		//layout.addButton(new SimpleButton(new Command("Test ID Link",testLinkIdentity)));
		layout.addButton(new SimpleButton(new Command("Get Attrib", testAttributionData)));
		//layout.addButton(new SimpleButton(new Command("Logging On", testEnableLogging)));
		//layout.addButton(new SimpleButton(new Command("Logging Off", testDisableLogging)));
		//layout.addButton(new SimpleButton(new Command("Limit app tracking - YES", testLimitAdTrackingTrue)));
		//layout.addButton(new SimpleButton(new Command("Limit app tracking - NO", testLimitAdTrackingFalse)));
		layout.addButton(new SimpleButton(new Command("Test Deep Link", testDeepLink)));
		
		layout.attach(buttonContainer);
		layout.layout();	
	}
	
	/** Log */
	private function log(msg:String):void
	{
		trace("[kcAIR] "+msg);
		txtStatus.text=msg;
	}	

	/** Print Response */
	private function printAttrData(msg:String):void
	{
		trace("[kcAIR] Printing Kochava attribution data");
		txtStatus.text = msg + txtStatus.text;
		
	}	
	
}
}


import flash.display.DisplayObjectContainer;
import flash.display.Sprite;
import flash.events.MouseEvent;
import flash.geom.Rectangle;
import flash.text.TextField;
import flash.text.TextFieldAutoSize;
import flash.text.TextFormat;

/** Simple Button */
class SimpleButton extends Sprite
{
	//
	// Instance Variables
	//
	
	/** Command */
	private var cmd:Command;
	
	/** Width */
	private var _width:Number;
	
	/** Label */
	private var txtLabel:TextField;
	
	//
	// Public Methods
	//
	
	/** Create New SimpleButton */
	public function SimpleButton(cmd:Command)
	{
		super();
		this.cmd=cmd;
		
		mouseChildren=false;
		mouseEnabled=buttonMode=useHandCursor=true;
		
		txtLabel=new TextField();
		txtLabel.defaultTextFormat=new TextFormat("Arial",32,0xFFFFFF);
		txtLabel.mouseEnabled=txtLabel.mouseEnabled=txtLabel.selectable=false;
		txtLabel.text=cmd.getLabel();
		txtLabel.autoSize=TextFieldAutoSize.LEFT;
		
		redraw();
		
		addEventListener(MouseEvent.CLICK,onSelect);
	}
	
	/** Set Width */
	override public function set width(val:Number):void
	{
		this._width=val;
		redraw();
	}

	
	/** Dispose */
	public function dispose():void
	{
		removeEventListener(MouseEvent.CLICK,onSelect);
	}
	
	//
	// Events
	//
	
	/** On Press */
	private function onSelect(e:MouseEvent):void
	{
		this.cmd.execute();
	}
	
	//
	// Implementation
	//
	
	/** Redraw */
	private function redraw():void
	{		
		txtLabel.text=cmd.getLabel();
		_width=_width||txtLabel.width*1.1;
		
		graphics.clear();
		graphics.beginFill(0x444444);
		graphics.lineStyle(2,0);
		graphics.drawRoundRect(0,0,_width,txtLabel.height*2,txtLabel.height*.4);
		graphics.endFill();
		
		txtLabel.x=_width/2-(txtLabel.width/2);
		txtLabel.y=txtLabel.height*.5;
		addChild(txtLabel);
	}
}

/** Button Layout */
class ButtonLayout
{
	private var buttons:Array;
	private var rect:Rectangle;
	private var padding:Number;
	private var parent:DisplayObjectContainer;
	
	public function ButtonLayout(rect:Rectangle,padding:Number)
	{
		this.rect=rect;
		this.padding=padding;
		this.buttons=new Array();
	}
	
	public function addButton(btn:SimpleButton):uint
	{
		return buttons.push(btn);
	}
	
	public function attach(parent:DisplayObjectContainer):void
	{
		this.parent=parent;
		for each(var btn:SimpleButton in this.buttons)
		{
			parent.addChild(btn);
		}
	}
	
	public function layout():void
	{
		var btnX:Number=rect.x+padding;
		var btnY:Number=rect.y;
		for each( var btn:SimpleButton in this.buttons)
		{
			btn.width=rect.width-(padding*2);
			btnY+=this.padding;
			btn.x=btnX;
			btn.y=btnY;
			btnY+=btn.height;
		}
	}
}

/** Inline Command */
class Command
{
	/** Callback Method */
	private var fnCallback:Function;
	
	/** Label */
	private var label:String;
	
	//
	// Public Methods
	//
	
	/** Create New Command */
	public function Command(label:String,fnCallback:Function)
	{
		this.fnCallback=fnCallback;
		this.label=label;
	}
	
	//
	// Command Implementation
	//
	
	/** Get Label */
	public function getLabel():String
	{
		return label;
	}
	
	/** Execute */
	public function execute():void
	{
		fnCallback();
	}
}